@@ -3,5 +3,9 @@ from ..task import Task
 
 
 class Job(Protocol):
+    name: str = ''
+    timeout: int = 600
+    frequency: str = '* * * * *'
+
     async def __call__(self, task: Task) -> Dict:
         """Job callback to be executed."""
